import { isNil, isString, isNumber, isRegExp, isDate, isFunction, isArray, camelCase, snakeCase, isObject } from "lodash-es";
const toCamleObject = (source, target) => {
  if (isNil(source) || isString(source) || isNumber(source) || isRegExp(source) || isDate(source) || isFunction(source)) {
    return source;
  }
  if (isArray(source)) {
    return source.map((v) => toCamleObject(v));
  }
  const res = target ?? {};
  for (const prop in source) {
    const val = source[prop];
    if (prop.startsWith("@")) {
      res[prop] = toCamleObject(val);
    } else {
      res[camelCase(prop)] = toCamleObject(val);
    }
  }
  return res;
};
const toSnakeObject = (source, target) => {
  if (isNil(source) || isString(source) || isNumber(source) || isRegExp(source) || isDate(source) || isFunction(source)) {
    return source;
  }
  if (isArray(source)) {
    return source.map((v) => toSnakeObject(v));
  }
  const res = target ?? {};
  for (const prop in source) {
    const val = source[prop];
    if (prop.startsWith("@")) {
      res[prop] = toSnakeObject(val);
    } else {
      res[snakeCase(prop)] = toSnakeObject(val);
    }
  }
  return res;
};
const asArray = (v) => {
  if (isNil(v)) {
    return [];
  }
  if (isArray(v)) {
    return v;
  }
  return [v];
};
const awaitGet = (v, ...restArgs) => {
  if (isFunction(v)) {
    const fun = v;
    v = fun(...restArgs);
  }
  if (isPromise(v)) {
    return Promise.all([v])[0];
  } else {
    return v;
  }
};
const isPromise = (val) => {
  return isObject(val) && isFunction(val["then"]) && isFunction(val["catch"]);
};
let id = 1;
const useID = (prefix) => {
  return (prefix ?? "") + ++id;
};
let msg;
function useMessage(msgType) {
  const _msg = msg;
  if (isNil(_msg)) {
    throw new Error("Please use `setupMessage()` or `provide(MessageSymbol, v)` first before call `useMessage()`");
  }
  if (!isNil(msgType)) {
    return _msg[msgType];
  }
  return _msg;
}
const setupMessage = (_msg) => {
  msg = _msg;
};
export {
  toCamleObject as a,
  asArray as b,
  awaitGet as c,
  useMessage as d,
  isPromise as i,
  setupMessage as s,
  toSnakeObject as t,
  useID as u
};
